intelmq.bots.parsers.phishtank package — intelmq 3.1.0.alpha1 documentation

# intelmq.bots.parsers.phishtank package

## Submodules

## intelmq.bots.parsers.phishtank.parser module

intelmq.bots.parsers.phishtank.parser.BOT

  alias of `intelmq.bots.parsers.phishtank.parser.PhishTankParserBot`

class intelmq.bots.parsers.phishtank.parser.PhishTankParserBot(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.ParserBot`

  Parse the PhishTank feed

  process()

## Module contents